@@ -7,7 +7,7 @@
 #include "dbus.h"
 #include "notify.h"
 
-int notify(sd_bus *bus, char *summary, char *body, uint32_t *id, enum urgency urgency) {
+int notify(sd_bus *bus, char *summary, char *body, char *category, uint32_t *id, enum urgency urgency) {
 	sd_bus_error error = SD_BUS_ERROR_NULL;
 	sd_bus_message *msg = NULL;
 	int ret = sd_bus_call_method(bus,
@@ -24,8 +24,9 @@ int notify(sd_bus *bus, char *summary, char *body, uint32_t *id, enum urgency ur
 	    summary,
 	    body,
 	    0,
-	    1,
+	    2,
 	    "urgency", "y", (uint8_t)urgency,
+	    "category", "s", category,
 	    -1);
 
 	if (ret < 0) {
